==========
Changelog
==========

This project adheres to `Semantic Versioning <https://semver.org/>`_.


0.1.0 (2021-04-01)
-----------------------

**Added**

* Created the project using cookietemple version 1.2.4

**Fixed**

**Dependencies**

**Deprecated**
